My Fridge List | Untappd
Author: The Untappd Team
Description: Wardy's List on Untappd including ratings, descriptions and more.
Keywords: Wardy's List on Untappd including ratings, descriptions and more.

### My Fridge

What’s in my fridge queue. May be unique but they’re in the queue. “Fridge” used liberally - might be in cupboard

18 Items • Updated
Back to Lists

## The Cool Kids – No Flower West Coast IPA

### Frenchies Brewery

#### IPA - American • 6.5% ABV • N/A IBU

(3.67 Avg)

Added on

Show Details
Add

- Notes

  Emma Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## Core Workout - IPA

### Hawkers Beer

#### IPA - American • 6% ABV • N/A IBU

(3.87 Avg)

Added on

Show Details
Add

- Notes

  Emma Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## City of Dreams Vienna IPA

### Bright Brewery

#### IPA - Other • 6.5% ABV • 55 IBU

(3.81 Avg)

Added on

Show Details
Add

- Notes

  Emma Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## Happy Chappy

### Five Barrel Brewing

#### IPA - Session • 4.5% ABV • N/A IBU

(3.68 Avg)

Added on

Show Details
Add

- Notes

  Emma Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## West Coast IPA - Core Range

### Rocks Brewing Co

#### IPA - American • 6.3% ABV • 60 IBU

(3.66 Avg)

Added on

Show Details
Add

- Notes

  Emma Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## Black Forest S'mores-Man Barrel Aged Milk Stout

### Wolf Of The Willows

#### Stout - Milk / Sweet • 5.8% ABV • 20 IBU

(3.89 Avg)

Added on

Show Details
Add

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Winona

- Purchase Price

  9.45

## Mid Tide Manly

### Beaches Brewery

#### Lager - Pale • 3.5% ABV • 18 IBU

Added on

Show Details
Add

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Winona

- Purchase Price

  4.50

## Imperial Logic: Volume 2

### Mountain Culture Beer Co.

#### Stout - Imperial / Double Pastry • 10.5% ABV • N/A IBU

(4.26 Avg)

Added on

Show Details
Add

- Notes

  Greg via Corey

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## South Coast Session

### Cupitt Craft Brewers

#### IPA - Session • 3.5% ABV • 25 IBU

(3.47 Avg)

Added on

Show Details
Add

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Cupitt’s Estate

## Triple Mot

### Bracket Brewing

#### IPA - Triple New England / Hazy • 9.7% ABV • N/A IBU

(4.5 Avg)

Added on

Show Details
Add

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Murray's Porters Liquor Glenbrook

## Bright Raspberry Beer

### Billson's 1865

#### Fruit Beer • 3.5% ABV • N/A IBU

(3.25 Avg)

Added on

Show Details
Add

- Notes

  Tracy Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## Botany Brew Fruity Beer Yuzu Citrus

### Hawkesbury Brewing Company

#### Fruit Beer • 4.2% ABV • N/A IBU

(2.37 Avg)

Added on

Show Details
Add

- Notes

  Tracy Xmas

- Quantity

  1

- Serving Style

  Can

- Purchase Date

## Dolly Aldrin - Melon Berliner Weisse

### Yulli's Brews

#### Sour - Fruited Berliner Weisse • 3.4% ABV • 10 IBU

(3.49 Avg)

Added on

Show Details
Add

- Notes

  ORIGIN Alexandria, NSW DESCRIPTION A traditional German style sour wheat ale, where low alcohol, tartness, & fruit combine to create the ultimate quencher. Ft cold pressed beetroot & apple.

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Winona

- Purchase Price

  8.64

## Chill Zone

### Mountain Culture Beer Co.

#### Pale Ale - American • 5.6% ABV • N/A IBU

(3.97 Avg)

Added on

Show Details
Add

- Quantity

  1

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Mountain Culture Beer Co.

- Purchase Price

  14.25

## Powder Day Salted Caramel Peanut Brittle

### Nomad Brewing Co.

#### Stout - Imperial / Double Milk • 7.8% ABV • N/A IBU

(4.05 Avg)

Added on

Show Details
Add

- Quantity

  2

- Serving Style

  Can

- Purchase Date

- Purchase Location

  Nomad Brewing Co. & Transit Lounge Bar

- Purchase Price

  13.00

Show More